==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Tm Konular");
define("_NOCOMMENTS","Yorum Yok");
define("_UCOMMENT","Yorum");
define("_REVIEWS","zlenimler");
define("_SEARCHUSERS","Kullanc Veritabannda Ara");
define("_SEARCHSECTIONS","zel Blmlerde Ara");
define("_SEARCHREVIEWS","zlenimlerde Ara");
define("_SEARCHIN","Ara:");
define("_ARTICLES","Haber");
define("_ALLAUTHORS","Tm Yazarlar");
define("_ALL","Tm");
define("_WEEK","hafta");
define("_WEEKS","hafta");
define("_MONTH","ay");
define("_MONTHS","ay");
define("_SEARCHON","Ara:");
define("_SSTORIES","Haber");
define("_SSECTIONS","Blmler");
define("_SUSERS","Kullanclar");
define("_NOMATCHES","Uygun sonu bulunamad");
define("_PREVMATCHES","nceki sonular");
define("_NEXTMATCHES","sonraki sonular");
define("_INSECTION","Makale Bulunuyor");
define("_NONAME","sim girilmemi");
define("_SCOMMENTS","Yorum");
define("_SEARCHRESULTS","Arama Sonular");
define("_CONTRIBUTEDBY","Katkda bulunan");
define("_UCOMMENTS","Yorum");
define("_MATCHTITLE","Balk");
define("_MATCHTEXT","Haber Metni");
define("_MATCHBOTH","Balk ve Haber Metni");
define("_SREPLY","Cevap");
define("_SREPLIES","Cevap");
define("_ATTACHART","Habere Eklenmi");
define("_PAGES","Sayfa");
define("_REVIEWSCORE","zlenim Puan");
define("_PAGE","Sayfa");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Tm Konular");
define("_NOCOMMENTS","Yorum Yok");
define("_UCOMMENT","Yorum");
define("_REVIEWS","zlenimler");
define("_SEARCHUSERS","Kullanc Veritabannda Ara");
define("_SEARCHSECTIONS","zel Blmlerde Ara");
define("_SEARCHREVIEWS","zlenimlerde Ara");
define("_SEARCHIN","Ara:");
define("_ARTICLES","Haber");
define("_ALLAUTHORS","Tm Yazarlar");
define("_ALL","Tm");
define("_WEEK","hafta");
define("_WEEKS","hafta");
define("_MONTH","ay");
define("_MONTHS","ay");
define("_SEARCHON","Ara:");
define("_SSTORIES","Haber");
define("_SSECTIONS","Blmler");
define("_SUSERS","Kullanclar");
define("_NOMATCHES","Uygun sonu bulunamad");
define("_PREVMATCHES","nceki sonular");
define("_NEXTMATCHES","sonraki sonular");
define("_INSECTION","Makale Bulunuyor");
define("_NONAME","sim girilmemi");
define("_SCOMMENTS","Yorum");
define("_SEARCHRESULTS","Arama Sonular");
define("_CONTRIBUTEDBY","Katkda bulunan");
define("_UCOMMENTS","Yorum");
define("_MATCHTITLE","Balk");
define("_MATCHTEXT","Haber Metni");
define("_MATCHBOTH","Balk ve Haber Metni");
define("_SREPLY","Cevap");
define("_SREPLIES","Cevap");
define("_ATTACHART","Habere Eklenmi");
define("_PAGES","Sayfa");
define("_REVIEWSCORE","zlenim Puan");
define("_PAGE","Sayfa");

?>
